OC.L10N.register(
    "groupfolders",
    {
    "Unset" : "Retirar",
    "Denied (Inherited permission)" : "Negado (permissões herdadas)",
    "Allowed (Inherited permission)" : "Permitido (permissão herdada)",
    "Denied" : "Negado",
    "Allowed" : "Permitido",
    "Access denied" : "Acesso proibido",
    "Inherit permission" : "Herdar permissão",
    "Deny" : "Negar",
    "Allow" : "Permitir",
    "Group" : "Grupo",
    "Read" : "Ler",
    "Write" : "Escrever",
    "Create" : "Criar",
    "Delete" : "Apagar",
    "Share" : "Partilhar",
    "You" : "Você",
    "Remove access rule" : "Remover regra de acesso",
    "Add advanced permission rule" : "Adicionar regra de permissões avançadas",
    "Select a user or group" : "Selecionar utilizador ou grupo",
    "Add group" : "Adicionar grupo",
    "Default" : "Predefinido",
    "Unlimited" : "Ilimitado",
    "Delete \"{folderName}\"?" : "Apagar \"{folderName}\"?",
    "Folder name" : "Nome da pasta",
    "Quota" : "Quota",
    "Advanced Permissions" : "Permissões avançadas",
    "Previous" : "Anterior",
    "Next" : "Seguinte",
    "User" : "Utilizador",
    "Unknown" : "Desconhecido",
    "None" : "Nenhum",
    "{size} used" : "{size} utilizado"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
